==> estateplat-common-1.2.4-20210727.071042-830-sources.jar: cn/gtmap/estateplat/model/server/core/BdcLdjyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:zhangyu@gtmap.cn">zhangyu</a>
 * @version V1.0, 2021/7/14
 * @description 林地经营权
 */
@Table(name = "BDC_LDJYQ")
public class BdcLdjyq extends QllxParent implements QllxVo{

    private static final long serialVersionUID = -992066970057359688L;

    private String fj;
    private String bz;//
    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登簿时间
    private Date jykssj;//经营起始时间
    private Date jyjssj;//经营结束时间
    private String jyyt;//经营用途
    private Double zbjg;//转包价格（元）
    private String jyfw;//经营范围（地块四至）
    private Double jymj;//经营面积（亩）
    private Double scmj;//实测面积（亩）
    private String tdyt;//土地用途
    private String qlxz;//权利性质
    private String htbh;//合同编号
    private String qlrmc;//权利人名称
    private String zxywh;//注销业务号
    @Override
    public String getFj() {
        return fj;
    }

    @Override
    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getQlxz() {
        return qlxz;
    }

    public void setQlxz(String qlxz) {
        this.qlxz = qlxz;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public Date getJykssj() {
        return jykssj;
    }

    public void setJykssj(Date jykssj) {
        this.jykssj = jykssj;
    }

    public Date getJyjssj() {
        return jyjssj;
    }

    public void setJyjssj(Date jyjssj) {
        this.jyjssj = jyjssj;
    }

    public String getJyyt() {
        return jyyt;
    }

    public void setJyyt(String jyyt) {
        this.jyyt = jyyt;
    }

    public Double getZbjg() {
        return zbjg;
    }

    public void setZbjg(Double zbjg) {
        this.zbjg = zbjg;
    }

    public String getJyfw() {
        return jyfw;
    }

    public void setJyfw(String jyfw) {
        this.jyfw = jyfw;
    }

    public Double getJymj() {
        return jymj;
    }

    public void setJymj(Double jymj) {
        this.jymj = jymj;
    }

    public Double getScmj() {
        return scmj;
    }

    public void setScmj(Double scmj) {
        this.scmj = scmj;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }
}

==> estateplat-common-1.2.4-20230608.071130-1175-sources.jar: cn/gtmap/estateplat/model/server/core/BdcLdjyq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * @author <a href="mailto:zhangyu@gtmap.cn">zhangyu</a>
 * @version V1.0, 2021/7/14
 * @description 林地经营权
 */
@Table(name = "BDC_LDJYQ")
public class BdcLdjyq extends QllxParent implements QllxVo {

    private static final long serialVersionUID = -992066970057359688L;

    private String fj;
    private String bz;//
    private String zxyy;//注销原因
    private String zxdbr;//注销登簿人
    private Date zxdbsj;//注销登簿时间
    private Date jykssj;//经营起始时间
    private Date jyjssj;//经营结束时间
    private String jyyt;//经营用途
    private Double zbjg;//转包价格（元）
    private String jyfw;//经营范围（地块四至）
    private Double jymj;//经营面积（亩）
    private Double scmj;//实测面积（亩）
    private String tdyt;//土地用途
    private String qlxz;//权利性质
    private String htbh;//合同编号
    private String qlrmc;//权利人名称
    private String zxywh;//注销业务号

    private String fbfdm;//发包方代码
    private String cbhtbm;//承包合同代码
    private String ydyhfl;//用地用海分类
    private String tdcbht;//土地承包合同

    public String getFbfdm() {
        return fbfdm;
    }

    public void setFbfdm(String fbfdm) {
        this.fbfdm = fbfdm;
    }

    public String getCbhtbm() {
        return cbhtbm;
    }

    public void setCbhtbm(String cbhtbm) {
        this.cbhtbm = cbhtbm;
    }

    public String getYdyhfl() {
        return ydyhfl;
    }

    public void setYdyhfl(String ydyhfl) {
        this.ydyhfl = ydyhfl;
    }

    public String getTdcbht() {
        return tdcbht;
    }

    public void setTdcbht(String tdcbht) {
        this.tdcbht = tdcbht;
    }

    @Override
    public String getFj() {
        return fj;
    }

    @Override
    public void setFj(String fj) {
        this.fj = fj;
    }

    public String getQlxz() {
        return qlxz;
    }

    public void setQlxz(String qlxz) {
        this.qlxz = qlxz;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getZxyy() {
        return zxyy;
    }

    public void setZxyy(String zxyy) {
        this.zxyy = zxyy;
    }

    public String getZxdbr() {
        return zxdbr;
    }

    public void setZxdbr(String zxdbr) {
        this.zxdbr = zxdbr;
    }

    public Date getZxdbsj() {
        return zxdbsj;
    }

    public void setZxdbsj(Date zxdbsj) {
        this.zxdbsj = zxdbsj;
    }

    public Date getJykssj() {
        return jykssj;
    }

    public void setJykssj(Date jykssj) {
        this.jykssj = jykssj;
    }

    public Date getJyjssj() {
        return jyjssj;
    }

    public void setJyjssj(Date jyjssj) {
        this.jyjssj = jyjssj;
    }

    public String getJyyt() {
        return jyyt;
    }

    public void setJyyt(String jyyt) {
        this.jyyt = jyyt;
    }

    public Double getZbjg() {
        return zbjg;
    }

    public void setZbjg(Double zbjg) {
        this.zbjg = zbjg;
    }

    public String getJyfw() {
        return jyfw;
    }

    public void setJyfw(String jyfw) {
        this.jyfw = jyfw;
    }

    public Double getJymj() {
        return jymj;
    }

    public void setJymj(Double jymj) {
        this.jymj = jymj;
    }

    public Double getScmj() {
        return scmj;
    }

    public void setScmj(Double scmj) {
        this.scmj = scmj;
    }

    public String getTdyt() {
        return tdyt;
    }

    public void setTdyt(String tdyt) {
        this.tdyt = tdyt;
    }

    public String getHtbh() {
        return htbh;
    }

    public void setHtbh(String htbh) {
        this.htbh = htbh;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getZxywh() {
        return zxywh;
    }

    public void setZxywh(String zxywh) {
        this.zxywh = zxywh;
    }
}
